Module: ServiceObjects::Helpers::Validations
- Includes:
- ActiveModel::Validations, Messages
- Included in:
- Base
- Defined in:
- lib/service_objects/helpers/validations.rb
Overview
Note:
A target class should include the module
Features for service attributes validation
Instance Method Summary collapse
-
#valid? ⇒ Boolean
Runs validations and checks if the object is valid.
-
#validate! ⇒ self
Raises
ServiceObjects::Invalidwhen #valid? method fails.
Methods included from Messages
#add_message, #messages, #translate
Instance Method Details
#valid? ⇒ Boolean
Runs validations and checks if the object is valid
|
|
# File 'lib/service_objects/helpers/validations.rb', line 17
|